pub enum BlockError {
Incomplete,
InvalidEntryHash,
InvalidLastTick,
TooFewTicks,
TooManyTicks,
InvalidTickHashCount,
TrailingEntry,
DuplicateBlock,
}Variants
Incomplete
Block did not have enough ticks was not marked full and no shred with is_last was seen.
InvalidEntryHash
Block entries hashes must all be valid
InvalidLastTick
Blocks must end in a tick that has been marked as the last tick.
TooFewTicks
Blocks can not have missing ticks Usually indicates that the node was interrupted with a more valuable block during production and abandoned it for that more-favorable block. Leader sent data to indicate the end of the block.
TooManyTicks
Blocks can not have extra ticks
InvalidTickHashCount
All ticks must contain the same number of hashes within a block
TrailingEntry
Blocks must end in a tick entry, trailing transaction entries are not allowed to guarantee that each block has the same number of hashes
DuplicateBlock